@@ -31,9 +31,9 @@
 int main(int argc, char *argv[])
 {
     KAboutData aboutData(QStringLiteral("bluedevilsendfile"),
-                         i18n("Bluetooth Send File Helper"),
-                         bluedevil_version,
-                         i18n("Bluetooth Send File Helper"),
+                         i18n("Bluetooth Send File Wizard"),
+                         BLUEDEVIL_VERSION,
+                         i18n("Bluetooth Send File Wizard"),
                          KAboutLicense::GPL,
                          i18n("(c) 2010, UFO Coders"));
 
@@ -52,7 +52,7 @@ int main(int argc, char *argv[])
     KDBusService service;
 
     QCommandLineOption kioOption(QStringList() << QStringLiteral("kio") << QStringLiteral("k"));
-    kioOption.setValueName(QStringLiteral("bluetooth://mac"));
+    kioOption.setValueName(QStringLiteral("bluetooth://address"));
 
     QCommandLineOption ubiOption(QStringList() << QStringLiteral("ubi") << QStringLiteral("u"));
     ubiOption.setValueName(QStringLiteral("ubi"));
@@ -61,14 +61,13 @@ int main(int argc, char *argv[])
     filesOption.setValueName(QStringLiteral("files"));
 
     QCommandLineParser parser;
-    parser.setApplicationDescription(i18n("Bluetooth Send File Helper"));
-    parser.addVersionOption();
-    parser.addHelpOption();
     parser.addOption(kioOption);
     parser.addOption(ubiOption);
     parser.addOption(filesOption);
+    aboutData.setupCommandLine(&parser);
 
     parser.process(app);
+    aboutData.processCommandLine(&parser);
 
     QString deviceInfo = parser.value(ubiOption);
     if (deviceInfo.isEmpty()) {
